@@ -11,18 +11,14 @@ import time
 from subprocess import PIPE
 
 import pytest
-from async_generator import async_generator
-from async_generator import yield_
 from jupyter_core import paths
 from traitlets.config.loader import Config
 
 from ..manager import _ShutdownStatus
 from ..manager import start_new_async_kernel
 from ..manager import start_new_kernel
-from .utils import AsyncKernelManagerWithCleanup
 from .utils import AsyncKMSubclass
 from .utils import SyncKMSubclass
-from .utils import test_env
 from jupyter_client import AsyncKernelManager
 from jupyter_client import KernelManager
 
@@ -31,14 +27,6 @@ pjoin = os.path.join
 TIMEOUT = 30
 
 
-@pytest.fixture(autouse=True)
-def env():
-    env_patch = test_env()
-    env_patch.start()
-    yield
-    env_patch.stop()
-
-
 @pytest.fixture(params=["tcp", "ipc"])
 def transport(request):
     if sys.platform == "win32" and request.param == "ipc":  #
@@ -123,7 +111,7 @@ def zmq_context():
     ctx.term()
 
 
-@pytest.fixture(params=[AsyncKernelManager, AsyncKMSubclass, AsyncKernelManagerWithCleanup])
+@pytest.fixture(params=[AsyncKernelManager, AsyncKMSubclass])
 def async_km(request, config):
     km = request.param(config=config)
     return km
@@ -136,11 +124,9 @@ def async_km_subclass(config):
 
 
 @pytest.fixture
-@async_generator  # This is only necessary while Python 3.5 is support afterwhich both it and
-# yield_() can be removed
 async def start_async_kernel():
     km, kc = await start_new_async_kernel(kernel_name="signaltest")
-    await yield_((km, kc))
+    yield km, kc
     kc.stop_channels()
     await km.shutdown_kernel()
     assert km.context.closed
@@ -167,6 +153,9 @@ class TestKernelManagerShutDownGracefully:
     @pytest.mark.skipif(sys.platform == "win32", reason="Windows doesn't support signals")
     @pytest.mark.parametrize(*parameters)
     def test_signal_kernel_subprocesses(self, name, install, expected):
+        # ipykernel doesn't support 3.6 and this test uses async shutdown_request
+        if expected == _ShutdownStatus.ShutdownRequest and sys.version_info < (3, 7):
+            pytest.skip()
         install()
         km, kc = start_new_kernel(kernel_name=name)
         assert km._shutdown_status == _ShutdownStatus.Unset
@@ -181,6 +170,9 @@ class TestKernelManagerShutDownGracefully:
     @pytest.mark.skipif(sys.platform == "win32", reason="Windows doesn't support signals")
     @pytest.mark.parametrize(*parameters)
     async def test_async_signal_kernel_subprocesses(self, name, install, expected):
+        # ipykernel doesn't support 3.6 and this test uses async shutdown_request
+        if expected == _ShutdownStatus.ShutdownRequest and sys.version_info < (3, 7):
+            pytest.skip()
         install()
         km, kc = await start_new_async_kernel(kernel_name=name)
         assert km._shutdown_status == _ShutdownStatus.Unset
@@ -352,7 +344,7 @@ class TestParallel:
         self._run_signaltest_lifecycle(config)
         self._run_signaltest_lifecycle(config)
 
-    @pytest.mark.timeout(TIMEOUT)
+    @pytest.mark.timeout(TIMEOUT + 10)
     def test_start_parallel_thread_kernels(self, config, install_kernel):
         if config.KernelManager.transport == "ipc":  # FIXME
             pytest.skip("IPC transport is currently not working for this test!")
@@ -467,23 +459,6 @@ class TestAsyncKernelManager:
         )
         assert keys == expected
 
-    async def test_subclass_deprecations(self, async_km):
-        await async_km.start_kernel(stdout=PIPE, stderr=PIPE)
-        is_alive = await async_km.is_alive()
-        assert is_alive
-        assert isinstance(async_km, AsyncKernelManager)
-        await async_km.shutdown_kernel(now=True)
-        is_alive = await async_km.is_alive()
-        assert is_alive is False
-        assert async_km.context.closed
-
-        if isinstance(async_km, AsyncKernelManagerWithCleanup):
-            assert async_km.which_cleanup == "cleanup"
-        elif isinstance(async_km, AsyncKMSubclass):
-            assert async_km.which_cleanup == "cleanup_resources"
-        else:
-            assert hasattr(async_km, "which_cleanup") is False
-
     @pytest.mark.timeout(10)
     @pytest.mark.skipif(sys.platform == "win32", reason="Windows doesn't support signals")
     async def test_signal_kernel_subprocesses(self, install_kernel, start_async_kernel):
